CustomBorderRadius class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

size4 → const BorderRadius
size8 → const BorderRadius
size12 → const BorderRadius
size16 → const BorderRadius
size20 → const BorderRadius
size28 → const BorderRadius
size32 → const BorderRadius
size40 → const BorderRadius
size48 → const BorderRadius