CustomIconSize class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- size10 → const double
- size12 → const double
- size16 → const double
- size20 → const double
- size24 → const double
- size32 → const double
- size36 → const double
- size40 → const double
- size48 → const double
- size56 → const double
- size64 → const double
- size72 → const double
- size80 → const double
- size96 → const double
- size120 → const double