data/data library

Classes

DataState<T>
A data class that represents the state of a request encapsulating the result of type T or error of type Object.
GenericDataState
A data class that represents the state of a request, encapsulating the error in case of one.

Extensions

DataStateExtensions on DataState<T>
DataStatePatterns on DataState<T>
Adds pattern-matching-related methods to DataState.
GenericDataStateExtensions on GenericDataState
GenericDataStatePatterns on GenericDataState
Adds pattern-matching-related methods to GenericDataState.