GenericDataState class sealed

A data class that represents the state of a request, encapsulating the error in case of one.

Same as DataState but without the result.

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

GenericDataState.error(Object error)
const
factory
GenericDataState.idle()
const
factory
GenericDataState.loading()
const
factory
GenericDataState.success()
const
factory

Properties

error Object?

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
hasError bool

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
hashCode int
The hash code for this object.
no setterinherited
isIdle bool

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
isIdleOrLoading bool

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
isLoading bool

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
isSuccess bool

Available on GenericDataState, provided by the GenericDataStateExtensions extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>({required TResult idle(GenericDataStateIdle value), required TResult loading(GenericDataStateLoading value), required TResult error(GenericDataStateError value), required TResult success(GenericDataStateSuccess value)}) → TResult

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? idle(GenericDataStateIdle value)?, TResult? loading(GenericDataStateLoading value)?, TResult? error(GenericDataStateError value)?, TResult? success(GenericDataStateSuccess value)?}) → TResult?

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult idle(GenericDataStateIdle value)?, TResult loading(GenericDataStateLoading value)?, TResult error(GenericDataStateError value)?, TResult success(GenericDataStateSuccess value)?, required TResult orElse()}) → TResult

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult idle()?, TResult loading()?, TResult error(Object error)?, TResult success()?, required TResult orElse()}) → TResult

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDataState<T>(T? successValue) DataState<T>

Available on GenericDataState, provided by the GenericDataStateExtensions extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>({required TResult idle(), required TResult loading(), required TResult error(Object error), required TResult success()}) → TResult

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? idle()?, TResult? loading()?, TResult? error(Object error)?, TResult? success()?}) → TResult?

Available on GenericDataState, provided by the GenericDataStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited