CustomError class

Constructors

CustomError({required Object? error, required StackTrace? stackTrace, DateTime? dateTime, String? customMessage, Map<String, Object>? parameters})

Properties

customMessage String?
final
dateTime DateTime?
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, Object>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final

Methods

copyWith({Object? error, StackTrace? stackTrace, DateTime? dateTime, String? customMessage, Map<String, Object>? parameters}) CustomError
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited