CustomLogger class
Constructors
- CustomLogger({required Logger logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
customError(
CustomError error) → Future< CustomError> -
debug(
String text) → void -
error(
dynamic error, {StackTrace? stackTrace, String? customMessage, String? errorName, Map< String, Object> ? parameters, bool reportOnSentry = true}) → Future<CustomError> -
info(
String text) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printWrapped(
String text) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- logDateFormat → DateFormat
-
final