ScreenSizeService class
- Inheritance
-
- Object
- ChangeNotifier
- SafeChangeNotifier
- ScreenSizeService
Constructors
Properties
- constraints → BoxConstraints
-
no setter
- devicePixelRatio → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDesktop → bool
-
no setter
- isMobile → bool
-
no setter
- isTablet → bool
-
no setter
- maxLayoutWidth → double
-
no setter
- mediaQueryData → MediaQueryData
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenHeight → double
-
no setter
- screenWidth → double
-
no setter
- textScaleFactor → double
-
no setter
- viewInsets → EdgeInsets
-
no setter
- viewPadding → EdgeInsets
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setDisposed(
) → void -
inherited
-
setSizes(
{required MediaQueryData mediaQueryData, required BoxConstraints constraints}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- desktopBreakpoint → const double
- tabletBreakpoint → const double